!WRF:MODEL_LAYER:PHYSICS
!
MODULE module_sf_flake

CONTAINS






   SUBROUTINE flake ( dMsnowdt_in, swdown, lwdn, height_u_in, height_tq_in,   &
                       UV, T2, Q2, psfc,  lh, hfx,     &                         
                       lake_depth, lake_depth_real, fetch, depth_bs, T_bs, f, dt,     &                         
                       T_snow_lake, T_ice_lake, T_mnw_lake, T_wML_lake, T_bot_lake, T_B1_lake,  & 
                       C_T_lake, h_snow_lake, h_ice_lake, h_ML_lake, H_B1_lake, T_sfc_lake,  & 
                       transparent )


  !-------------------------------------------------     


   USE module_wrf_error

   USE module_sf_flake_parameters

   USE module_sf_flake_model

   USE module_sf_flake_sfcflx


   IMPLICIT NONE

  !-------------------------------------------------     
       REAL, INTENT(INOUT)::                            &
    &       T_snow_lake                                 &
    &       , T_ice_lake, T_mnw_lake                    &
    &       , T_wML_lake, T_bot_lake                    &
    &       , T_B1_lake, C_T_lake                       &
    &       , h_snow_lake, h_ice_lake                   &
    &       , h_ML_lake, H_B1_lake                      &
    &       , T_sfc_lake                             

       REAL, INTENT(IN)::                               &
    &       lwdn, swdown, lh, hfx                       &
    &       , psfc, T2, Q2, UV

       REAL, INTENT(IN)::                               &
    &           lake_depth, lake_depth_real

    REAL , INTENT(IN) ::                                &
    &    dt, f                       

    INTEGER , INTENT(IN) ::                             &
    &   transparent

    REAL , INTENT(IN) ::                                &
    &    height_u_in                                  , & ! Height above the lake surface where the wind speed is measured [m]
    &    height_tq_in                                 , & ! Height where temperature and humidity are measured [m]
    &    dMsnowdt_in                                  , & ! The rate of snow accumulation [kg m^{-2} s^{-1}]
    &    fetch                                        , & ! Typical wind fetch [m]
    &    depth_bs                                     , & ! Depth of the thermally active layer of the bottom sediments [m]
    &    T_bs                                             ! Temperature at the outer edge of 
                                                          ! the thermally active layer of the bottom sediments [K]
!-------------------------------------------------
!LOCAL
!-------------------------------------------------

!  Input/Output (procedure arguments)

    REAL :: &
      albedo_water                        , & ! Water surface albedo with respect to the solar radiation
      albedo_ice                          , & ! Ice surface albedo with respect to the solar radiation
      albedo_snow                             ! Snow surface albedo with respect to the solar radiation

    TYPE (opticpar_medium) :: & 
      opticpar_water                       , & ! Optical characteristics of water
      opticpar_ice                         , & ! Optical characteristics of ice
      opticpar_snow                            ! Optical characteristics of snow 

       CHARACTER*256 :: message

    REAL ::    &
      Q_momentum             , & ! Momentum flux [N m^{-2}]
      Q_sensible             , & ! Sensible heat flux [W m^{-2}]
      Q_latent               , & ! Latent heat flux [W m^{-2}]
      Q_watvap                   ! Flux of water vapour [kg m^{-2} s^{-1}]

    REAL ::    &
      T_sfc_p               , & 
      T_sfc_n



!==============================================================================
!  Start calculations
!------------------------------------------------------------------------------

!------------------------------------------------------------------------------
!  Set initial values
!------------------------------------------------------------------------------

    if (T_mnw_lake.eq.0) then ! No init data for the lake - set well mixed water at sfc temperature

          T_snow_p_flk = 0. + 273.15
          T_ice_p_flk = 0. + 273.15
          T_mnw_p_flk = T_sfc_lake
          T_wML_p_flk = T_sfc_lake
          T_bot_p_flk = T_sfc_lake
          T_B1_p_flk = T_sfc_lake
          C_T_p_flk = 0.5
          h_snow_p_flk = 0.
          h_ice_p_flk = 0.
          h_ML_p_flk = 0.
          H_B1_p_flk = 5.
          T_sfc_p = T_sfc_lake

    else

        T_snow_p_flk = T_snow_lake    
        T_ice_p_flk = T_ice_lake
        T_mnw_p_flk = T_mnw_lake
        T_wML_p_flk = T_wML_lake
        T_bot_p_flk = T_bot_lake
        T_B1_p_flk = T_B1_lake
        C_T_p_flk = C_T_lake
        h_snow_p_flk = h_snow_lake
        h_ice_p_flk = h_ice_lake  
        h_ML_p_flk = h_ML_lake
        H_B1_p_flk = H_B1_lake
        T_sfc_p = T_sfc_lake

    endif



!------------------------------------------------------------------------------
!  Set albedos of the lake water, lake ice and snow
!------------------------------------------------------------------------------

! Use default value 
albedo_water = albedo_water_ref
! Use empirical formulation proposed by Mironov and Ritter (2004) for GME 
!_nu albedo_ice   = albedo_whiteice_ref 
albedo_ice   = EXP(-c_albice_MR*(tpl_T_f-T_sfc_p)/tpl_T_f)
albedo_ice   = albedo_whiteice_ref*(1.-albedo_ice) + albedo_blueice_ref*albedo_ice

albedo_snow  = albedo_ice  
! albedo_snow  = albedo_drysnow_ref

!------------------------------------------------------------------------------
!  Set optical characteristics of the lake water, lake ice and snow
!------------------------------------------------------------------------------

! Use default values

   IF(transparent.EQ.0) THEN        
       opticpar_water = opticpar_water_ref
   ELSE
       opticpar_water = opticpar_water_trans
   END IF

opticpar_ice   = opticpar_ice_opaque   ! Opaque ice

opticpar_snow  = opticpar_snow_opaque  ! Opaque snow



!------------------------------------------------------------------------------
!  Set the rate of snow accumulation
!------------------------------------------------------------------------------

    dMsnowdt_flk = dMsnowdt_in  


!------------------------------------------------------------------------------
!  Compute solar radiation fluxes (positive downward)
!------------------------------------------------------------------------------

     I_atm_flk = swdown

     CALL flake_radflux ( lake_depth, albedo_water, albedo_ice, albedo_snow, &
                             opticpar_water, opticpar_ice, opticpar_snow )



!------------------------------------------------------------------------------
!  Compute long-wave radiation fluxes (positive downward)
!------------------------------------------------------------------------------


     Q_w_flk = lwdn                                !Radiation of the atmosphere 

     Q_w_flk = Q_w_flk - SfcFlx_lwradwsfc(T_sfc_p)  ! Radiation of the surface (notice the sign)

!------------------------------------------------------------------------------
!  Compute the surface friction velocity and fluxes of sensible and latent heat 
!------------------------------------------------------------------------------

     CALL SfcFlx_momsenlat ( height_u_in, height_tq_in, fetch,       &
                            UV, T2, Q2, T_sfc_p, psfc, h_ice_p_flk,  &
                            Q_momentum, Q_sensible, Q_latent, Q_watvap )

    u_star_w_flk = SQRT(-Q_momentum/tpl_rho_w_r)


!------------------------------------------------------------------------------
!  Compute heat fluxes Q_snow_flk, Q_ice_flk, Q_w_flk
!------------------------------------------------------------------------------


    Q_w_flk = Q_w_flk - Q_sensible - Q_latent  ! Add sensible and latent heat fluxes (notice the signs)



!------------------------------------------------------------------------------

IF(h_ice_p_flk.GE.h_Ice_min_flk) THEN            ! Ice exists
  IF(h_snow_p_flk.GE.h_Snow_min_flk) THEN        ! There is snow above the ice
    Q_snow_flk = Q_w_flk
    Q_ice_flk  = 0.
    Q_w_flk    = 0.
  ELSE                                           ! No snow above the ice
    Q_snow_flk = 0.
    Q_ice_flk  = Q_w_flk
    Q_w_flk    = 0.
  END IF
ELSE                                             ! No ice-snow cover
    Q_snow_flk = 0.
    Q_ice_flk  = 0.
END IF

!------------------------------------------------------------------------------
!  Advance FLake variables
!------------------------------------------------------------------------------



 CALL flake_driver ( lake_depth, lake_depth_real, depth_bs, T_bs,      &
                     f, opticpar_water%extincoef_optic(1),             &
                     dt, T_sfc_p, T_sfc_n )



!------------------------------------------------------------------------------
!  Set output values
!------------------------------------------------------------------------------

    T_snow_lake = T_snow_n_flk  
    T_ice_lake  = T_ice_n_flk      
    T_mnw_lake  = T_mnw_n_flk     
    T_wML_lake  = T_wML_n_flk    
    T_bot_lake  = T_bot_n_flk   
    T_B1_lake   = T_B1_n_flk    
    C_T_lake    = C_T_n_flk     
    h_snow_lake = h_snow_n_flk   
    h_ice_lake  = h_ice_n_flk    
    h_ML_lake   = h_ML_n_flk     
    H_B1_lake   = H_B1_n_flk   
    T_sfc_lake  = T_sfc_n


!-------------------------------------------------
!-------------------------------------------------


   END SUBROUTINE flake

!-------------------------------------------------
!-------------------------------------------------








END MODULE module_sf_flake
