

MODULE module_sf_flake_parameters

!------------------------------------------------------------------------------
!MODULE flake_configure
!------------------------------------------------------------------------------
!
! Description:
!
!  Switches and reference values of parameters 
!  that configure the lake model FLake are set.


LOGICAL, PARAMETER :: &
  lflk_botsed_use   = .TRUE.         ! .TRUE. indicates that the bottom-sediment scheme is used
                                     ! to compute the depth penetrated by the thermal wave, 
                                     ! the temperature at this depth and the bottom heat flux.
                                     ! Otherwise, the heat flux at the water-bottom sediment interface
                                     ! is set to zero, the depth penetrated by the thermal wave 
                                     ! is set to a reference value defined below,
                                     ! and the temperature at this depth is set to 
                                     ! the temperature of maximum density of the fresh water.

REAL, PARAMETER :: &
  rflk_depth_bs_ref = 10.0    ! Reference value of the depth of the thermally active
                                     ! layer of bottom sediments [m].
                                     ! This value is used to (formally) define
                                     ! the depth penetrated by the thermal wave
                                     ! in case the bottom-sediment scheme is not used.


!-------------------------------------------------
!MODULE flake_derivedtypes
!-------------------------------------------------
!  Maximum value of the wave-length bands 
!  in the exponential decay law for the radiation flux.
!  A storage for a ten-band approximation is allocated,
!  although a smaller number of bands is actually used.

	INTEGER , PARAMETER :: & 
  	nband_optic_max = 10

	!  Define TYPE "opticpar_medium"
	TYPE opticpar_medium
  	INTEGER                         ::   & 
   	 nband_optic                                            ! Number of wave-length bands
  	REAL , DIMENSION (nband_optic_max) ::   & 
   	 frac_optic                                         , & ! Fractions of total radiation flux 
   	 extincoef_optic                                        ! Extinction coefficients 
	END TYPE opticpar_medium

!-------------------------------------------------
!MODULE flake_parameters
!-------------------------------------------------
!  Dimensionless constants 
!  in the equations for the mixed-layer depth 
!  and for the shape factor with respect to the temperature profile in the thermocline

REAL , PARAMETER ::         &
  c_cbl_1       = 0.17            , & ! Constant in the CBL entrainment equation
  c_cbl_2       = 1.              , & ! Constant in the CBL entrainment equation
  c_sbl_ZM_n    = 0.5             , & ! Constant in the ZM1996 equation for the equilibrium SBL depth
  c_sbl_ZM_s    = 10.             , & ! Constant in the ZM1996 equation for the equilibrium SBL depth
  c_sbl_ZM_i    = 20.             , & ! Constant in the ZM1996 equation for the equilibrium SBL depth
  c_relax_h     = 0.030           , & ! Constant in the relaxation equation for the SBL depth
  c_relax_C     = 0.0030              ! Constant in the relaxation equation for the shape factor
                                             ! with respect to the temperature profile in the thermocline

!  Parameters of the shape functions 
!  Indices refer to T - thermocline, S - snow, I - ice,
!  B1 - upper layer of the bottom sediments, B2 - lower layer of the bottom sediments.
!  "pr0" and "pr1" denote zeta derivatives of the corresponding shape function 
!  at "zeta=0" ad "zeta=1", respectively.
REAL , PARAMETER ::         &
  C_T_min       = 0.5             , & ! Minimum value of the shape factor C_T (thermocline)
  C_T_max       = 0.8             , & ! Maximum value of the shape factor C_T (thermocline)
  Phi_T_pr0_1   = 40./3.   , & ! Constant in the expression for the T shape-function derivative 
  Phi_T_pr0_2   = 20./3.   , & ! Constant in the expression for the T shape-function derivative 
  C_TT_1        = 11./18.  , & ! Constant in the expression for C_TT (thermocline)
  C_TT_2        = 7./45.   , & ! Constant in the expression for C_TT (thermocline)
  C_B1          = 2./3.    , & ! Shape factor (upper layer of bottom sediments)
  C_B2          = 3./5.    , & ! Shape factor (lower layer of bottom sediments)
  Phi_B1_pr0    = 2.              , & ! B1 shape-function derivative 
  C_S_lin       = 0.5             , & ! Shape factor (linear temperature profile in the snow layer)
  Phi_S_pr0_lin = 1.              , & ! S shape-function derivative (linear profile) 
  C_I_lin       = 0.5             , & ! Shape factor (linear temperature profile in the ice layer)
  Phi_I_pr0_lin = 1.              , & ! I shape-function derivative (linear profile) 
  Phi_I_pr1_lin = 1.              , & ! I shape-function derivative (linear profile) 
  Phi_I_ast_MR  = 2.              , & ! Constant in the MR2004 expression for I shape factor
  C_I_MR        = 1./12.   , & ! Constant in the MR2004 expression for I shape factor
  H_Ice_max     = 3.                  ! Maximum ice tickness in 
                                             ! the Mironov and Ritter (2004, MR2004) ice model [m] 

!  Security constants
REAL , PARAMETER ::         &
  h_Snow_min_flk = 1.0E-5         , & ! Minimum snow thickness [m]
  h_Ice_min_flk  = 1.0E-9         , & ! Minimum ice thickness [m]
  h_ML_min_flk   = 1.0E-2         , & ! Minimum mixed-layer depth [m]
  h_ML_max_flk   = 1.0E+3         , & ! Maximum mixed-layer depth [m]
  H_B1_min_flk   = 1.0E-3         , & ! Minimum thickness of the upper layer of bottom sediments [m]
  u_star_min_flk = 1.0E-6             ! Minimum value of the surface friction velocity [m s^{-1}]

!  Security constant(s)
REAL , PARAMETER ::         &
  c_small_flk    = 1.0E-10            ! A small number

!  Thermodynamic parameters
REAL , PARAMETER ::        &
  tpl_grav          = 9.81       , & ! Acceleration due to gravity [m s^{-2}]
  tpl_T_r           = 277.13     , & ! Temperature of maximum density of fresh water [K]
  tpl_T_f           = 273.15     , & ! Fresh water freezing point [K]
  tpl_a_T           = 1.6509E-05 , & ! Constant in the fresh-water equation of state [K^{-2}]
  tpl_rho_w_r       = 1.0E+03    , & ! Maximum density of fresh water [kg m^{-3}]
  tpl_rho_I         = 9.1E+02    , & ! Density of ice [kg m^{-3}]
  tpl_rho_S_min     = 1.0E+02    , & ! Minimum snow density [kg m^{-3}]
  tpl_rho_S_max     = 4.0E+02    , & ! Maximum snow density [kg m^{-3}]
  tpl_Gamma_rho_S   = 2.0E+02    , & ! Empirical parameter [kg m^{-4}]  
                                            ! in the expression for the snow density 
  tpl_L_f           = 3.3E+05    , & ! Latent heat of fusion [J kg^{-1}]
  tpl_c_w           = 4.2E+03    , & ! Specific heat of water [J kg^{-1} K^{-1}]
  tpl_c_I           = 2.1E+03    , & ! Specific heat of ice [J kg^{-1} K^{-1}]
  tpl_c_S           = 2.1E+03    , & ! Specific heat of snow [J kg^{-1} K^{-1}]
  tpl_kappa_w       = 5.46E-01   , & ! Molecular heat conductivity of water [J m^{-1} s^{-1} K^{-1}]
  tpl_kappa_I       = 2.29       , & ! Molecular heat conductivity of ice [J m^{-1} s^{-1} K^{-1}]
  tpl_kappa_S_min   = 0.2        , & ! Minimum molecular heat conductivity of snow [J m^{-1} s^{-1} K^{-1}]
  tpl_kappa_S_max   = 1.5        , & ! Maximum molecular heat conductivity of snow [J m^{-1} s^{-1} K^{-1}]
  tpl_Gamma_kappa_S = 1.3            ! Empirical parameter [J m^{-2} s^{-1} K^{-1}] 
                                            ! in the expression for the snow heat conductivity 



!-------------------------------------------------
!MODULE flake_paramoptic_ref
!-------------------------------------------------
! Description:
!
!  This module contains "reference" values of the optical characteristics
!  of the lake water, lake ice and snow. These reference values may be used 
!  if no information about the optical characteristics of the lake in question 
!  is available. An exponential decay law for the solar radiation flux is assumed.
!  In the simplest one-band approximation,
!  the extinction coefficient for water is set to a large value,
!  leading to the absorption of 95% of the incoming radiation 
!  within the uppermost 1 m of the lake water. 
!  The extinction coefficients for ice and snow are taken from 
!  Launiainen and Cheng (1998). The estimates for the ice correspond 
!  to the uppermost 0.1 m of the ice layer and to the clear sky conditions 
!  (see Table 2 in op. cit.).
!  Very large values of the extinction coefficients for ice and snow ("opaque")
!  can be used to prevent penetration of the solar radiation 
!  through the snow-ice cover.

INTEGER  :: & ! Help variable(s)
  i                                      ! DO loop index

!  Optical characteristics for water, ice and snow.
!  The simplest one-band approximation is used as a reference.
TYPE (opticpar_medium), PARAMETER ::                           & 
  opticpar_water_ref = opticpar_medium(1,                      & ! Water (reference)
    (/1., (0.,i=2,nband_optic_max)/),            &
    (/3., (1.E+10,i=2,nband_optic_max)/))      , &
  opticpar_water_trans = opticpar_medium(2,                             & ! Transparent Water (two-band)
    (/0.10, 0.90, (0.,i=3,nband_optic_max)/),      &
    (/2.0, 0.20, (1.E+10,i=3,nband_optic_max)/)) , &
!_nu  opticpar_water_trans = opticpar_medium(1,                    & ! Transparent Water (one-band)
!_nu    (/1., (0.,i=2,nband_optic_max)/),            &
!_nu    (/0.30, (1.E+10,i=2,nband_optic_max)/))    , &
  opticpar_whiteice_ref = opticpar_medium(1,                   & ! White ice
    (/1., (0.,i=2,nband_optic_max)/),            &   
    (/17.1, (1.E+10,i=2,nband_optic_max)/))    , &
  opticpar_blueice_ref = opticpar_medium(1,                    & ! Blue ice
    (/1., (0.,i=2,nband_optic_max)/),            &
    (/8.4, (1.E+10,i=2,nband_optic_max)/))     , &
  opticpar_drysnow_ref = opticpar_medium(1,                    & ! Dry snow 
    (/1., (0.,i=2,nband_optic_max)/),            &
    (/25.0, (1.E+10,i=2,nband_optic_max)/))    , &
  opticpar_meltingsnow_ref = opticpar_medium(1,                & ! Melting snow 
    (/1., (0.,i=2,nband_optic_max)/),            &
    (/15.0, (1.E+10,i=2,nband_optic_max)/))    , &
  opticpar_ice_opaque = opticpar_medium(1,                     & ! Opaque ice
    (/1., (0.,i=2,nband_optic_max)/),            &
    (/1.0E+07, (1.E+10,i=2,nband_optic_max)/)) , &
  opticpar_snow_opaque = opticpar_medium(1,                    & ! Opaque snow
    (/1., (0.,i=2,nband_optic_max)/),            &
    (/1.0E+07, (1.E+10,i=2,nband_optic_max)/)) 


!-------------------------------------------------
!MODULE flake_albedo_ref
!-------------------------------------------------
!  Albedo for water, ice and snow.

REAL , PARAMETER ::        &
  albedo_water_ref       = 0.08  , & ! Water
  albedo_whiteice_ref    = 0.80  , & ! White ice
  albedo_blueice_ref     = 0.10  , & ! Blue ice
  albedo_drysnow_ref     = 0.80  , & ! Dry snow 
  albedo_meltingsnow_ref = 0.10      ! Melting snow 

!  Empirical parameters.
REAL , PARAMETER :: &
  c_albice_MR = 95.6          ! Constant in the interpolation formula for 
                                     ! the ice albedo (Mironov and Ritter 2004)

!-------------------------------------------------



END MODULE module_sf_flake_parameters
